﻿#light
namespace Anderscui.FsSamples.UI

open System
open System.Windows.Forms

open Anderscui.CsWinUILib
open Anderscui.FsSamples.Common

type processFinderForm = class
    inherit ProcessChecker
    
    val mutable oldCursor : Cursor
    
    member this.initializeComponent() =
        this.btnListVisibleApps.Click.Add(this.btnListVisibleApps_Click)
        this.btnListProcesses.Click.Add(this.btnListProcesses_Click)
        this.btnListImageNames.Click.Add(this.btnListImageNames_Click)
        this.btnFindProByName.Click.Add(this.btnFindProByName_Click)
        this.btnFindProByImageName.Click.Add(this.btnFindProByImageName_Click)
        this.btnFindAppByName.Click.Add(this.btnFindAppByName_Click)
        
    new() as this = 
        { oldCursor = Cursors.Default }
        then
        this.initializeComponent()
            
    member private this.showWaitInfo() =
        this.oldCursor <- this.Cursor
        this.Cursor <- Cursors.WaitCursor
        
    member private this.hideWaitInfo() =
        this.Cursor <- this.oldCursor
        
    member private this.btnListVisibleApps_Click (e : EventArgs) =
        this.showWaitInfo()
        this.txtResultList.Clear()
        this.txtResultList.Text <- ProcessHelper.listAllApplications()
        this.hideWaitInfo()
        
    member private this.btnListProcesses_Click (e : EventArgs) =
        this.showWaitInfo()
        this.txtResultList.Clear()
        this.txtResultList.Text <- ProcessHelper.listAllProcesses()
        this.hideWaitInfo()
        
    member private this.btnListImageNames_Click (e : EventArgs) =
        this.showWaitInfo()
        this.txtResultList.Clear()
        this.txtResultList.Text <- ProcessHelper.listAllByImageName()
        this.hideWaitInfo()
        
    member private this.btnFindProByName_Click (e : EventArgs) =
        let hasText = this.checkRequiredTextBox this.txtProcessName "Input Process Name"
        if hasText then
            let processName = this.txtProcessName.Text
            let found = ProcessHelper.checkForProcessByName processName
            
            if found then
                MessageBox.Show(processName + " process name found.") |> ignore
            else
                MessageBox.Show(processName + " process name not found.") |> ignore
        else
            ()
    
    member private this.btnFindProByImageName_Click (e : EventArgs) =
        let hasText = this.checkRequiredTextBox this.txtProcessImageName "Input Image Name"
        if hasText then
            let imageName = this.txtProcessImageName.Text
            let found = ProcessHelper.checkForProcessByImageName imageName
            
            if found then
                MessageBox.Show(imageName + " image name found.") |> ignore
            else
                MessageBox.Show(imageName + " image name not found.") |> ignore
        else
            ()
            
    member private this.btnFindAppByName_Click (e : EventArgs) =
        let hasText = this.checkRequiredTextBox this.txtApplicationName "Input App Name"
        if hasText then
            let appName = this.txtApplicationName.Text
            let found = ProcessHelper.checkForApplicationByName appName
            
            if found then
                MessageBox.Show(appName + " application name found.") |> ignore
            else
                MessageBox.Show(appName + " application name not found.") |> ignore
        else
            ()
    
    member private this.checkRequiredTextBox (textbox: TextBox) (message: string) =
        if String.IsNullOrEmpty(textbox.Text.Trim()) then
            MessageBox.Show(message) |> ignore
            textbox.Select()
            false
        else
            true    
end